# Generated by Django 4.1 on 2022-08-30 18:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='address',
            options={'ordering': ['first_name', 'last_name'], 'verbose_name_plural': 'Address Entries'},
        ),
        migrations.AlterModelOptions(
            name='person',
            options={'ordering': ['first_name', 'last_name']},
        ),
    ]
